@@ -6,6 +6,7 @@ from . import utils
 
 __all__ = ['wrap']
 
+
 class ProxyCursor(object):
 
     __INTERFACES = ['before_insert', 'before_update', 'after_insert', 'after_update']
@@ -85,7 +86,9 @@ class ProxyCursor(object):
             funcs = interfaces(handler)
             pre_execute(handler, funcs, dml_type.lower())
             result = self.__execute(query, args)
+            lastrowid = self.__cursor.lastrowid
             post_execute(handler, funcs, dml_type.lower(), result)
+            self.__cursor.lastrowid = lastrowid
         return result
 
     def __execute(self, query, args=None):
